OC.L10N.register(
    "accessibility",
    {
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema oscuro para facilitar la vista al reducir la luminosidad y el brillo general. Todavía está en desarrollo, por lo tanto, informe cualquier problema que pueda encontrar.",
    "Dyslexia font" : "Dislexia fuente",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic es un tipo de letra/fuente gratuita diseñada para mitigar algunos de los errores comunes de lectura causados ​​por la dislexia.",
    "Accessibility" : "Accesibilidad",
    "Accessibility options for nextcloud" : "Opciones de accesibilidad para nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Proporciona múltiples opciones de accesibilidad para facilitar el uso de Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautas de accesibilidad de contenido web",
    "our issue tracker" : "nuestro rastreador de problemas",
    "our design team" : "nuestro equipo de diseño",
    "Enable" : "Habilitar",
    "High contrast theme" : "Tema de alto contraste",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de alto contraste para facilitar su navegación. Se reducirá la calidad visual pero se aumentará la claridad.",
    "Dark theme (beta)" : "Tema oscuro (beta)",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Proporciona múltiples opciones de accesibilidad para facilitar su uso de nextcloud"
},
"nplurals=2; plural=(n != 1);");
